(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     22963,        504]
NotebookOptionsPosition[     23137,        490]
NotebookOutlinePosition[     23856,        515]
CellTagsIndexPosition[     23813,        512]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Moment of a Force in 2D\n",
 StyleBox["Zhelong He, Marek-Jerzy Pindera \nUniversity of Virginia, \
2017-08-17",
  FontSize->16,
  FontColor->GrayLevel[0]]
}], "Title",
 TextAlignment->Center],

Cell[TextData[{
 "The moment of a force ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["F", "\[RightVector]"], TraditionalForm]]],
 " about point O, or actually about the moment axis passing through O and \
perpendicular to the plane containing O and ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["F", "\[RightVector]"], TraditionalForm]]],
 ", can be expressed using the vector cross product, namely ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     OverscriptBox["M", "\[RightVector]"], "O"], "=", 
    RowBox[{
     OverscriptBox["r", "\[RightVector]"], "\[Times]", 
     OverscriptBox["F", "\[RightVector]"]}]}], TraditionalForm]]],
 ". Here ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["r", "\[RightVector]"], TraditionalForm]]],
 " represents a position vector directed from O to any point on the line of \
action of ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["F", "\[RightVector]"], TraditionalForm]]],
 ". \nFor a beam with unbalanced moment ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["M", "\[RightVector]"], "O"], TraditionalForm]]],
 ", the equation of motion is described by ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     OverscriptBox["M", "\[RightVector]"], "O"], "=", " ", 
    RowBox[{
     SubscriptBox["I", "O"], 
     OverscriptBox[
      OverscriptBox["\[Theta]", "\[DoubleDot]"], "\[RightVector]"]}]}], 
   TraditionalForm]]],
 ", where ",
 Cell[BoxData[
  FormBox[
   OverscriptBox[
    OverscriptBox["\[Theta]", "\[DoubleDot]"], "\[RightVector]"], 
   TraditionalForm]]],
 " is the angular acceleration, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "O"], TraditionalForm]]],
 " is the moment of inertia with respect to O. If the beam is constrained to \
be rotate within certain plane, the equation of motion is simplified as ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["M", "O"], "=", " ", 
    RowBox[{
     SubscriptBox["I", "O"], 
     OverscriptBox["\[Theta]", "\[DoubleDot]"]}]}], TraditionalForm]]],
 ". So we see, in order to keep the beam in static, we need to make the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["M", "O"], TraditionalForm]]],
 " to zero. \nFor the following problem, we have two forces ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     OverscriptBox["F", "\[RightVector]"], "1"], ",", 
    SubscriptBox[
     OverscriptBox["F", "\[RightVector]"], "2"]}], TraditionalForm]]],
 ", with their magnitudes, directions and acting positions to be set. Both of \
them produce the moment with respect to hinge, and the resultant may cause \
the moment to rotate with respect to hinge. We can see the rotation once we \
set unbalanced moment of these two forces. Also, we can see that the beam \
will keep in static once the resultant moment is zero. "
}], "Text"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`F$$ = 0, $CellContext`l$$ = 
    0, $CellContext`lf$$ = 0, $CellContext`lr$$ = 0, $CellContext`opa1$$ = 
    0, $CellContext`R$$ = 0, $CellContext`\[Alpha]d$$ = 
    0, $CellContext`\[Beta]d$$ = 0, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`opa1$$], 0, 
       Row[{"Coordinates visibility", 
         Spacer[20]}]}, {1 -> "On", 0 -> "off"}}, {{
       Hold[$CellContext`l$$], 0, 
       Row[{"Hinge position (m)", 
         Spacer[2]}]}, 0, 3}, {{
       Hold[$CellContext`F$$], 0, 
       Row[{
        "\!\(\*\nStyleBox[SubscriptBox[\"F\", \"1\"],\nFontSlant->\"Italic\"]\
\) magnitude (N)", 
         Spacer[7]}]}, -3, 3}, {{
       Hold[$CellContext`\[Alpha]d$$], 0, 
       Row[{
        "Angle of \!\(\*\nStyleBox[SubscriptBox[\"F\", \"1\"],\n\
FontSlant->\"Italic\"]\)\!\(\*\nStyleBox[\" \",\nFontSlant->\"Italic\"]\): \!\
\(\*SubscriptBox[\(\[Alpha]\), \(1\)]\) (\[Degree])", 
         Spacer[0]}]}, 0, 360}, {{
       Hold[$CellContext`lf$$], 0, 
       Row[{
        "\!\(\*\nStyleBox[SubscriptBox[\"F\", \"1\"],\nFontSlant->\"Italic\"]\
\) position (m)", 
         Spacer[20]}]}, 0, 3}, {{
       Hold[$CellContext`R$$], 0, 
       Row[{
        "\!\(\*\nStyleBox[SubscriptBox[\"F\", \"2\"],\nFontSlant->\"Italic\"]\
\) magnitude (N)", 
         Spacer[7]}]}, -3, 3}, {{
       Hold[$CellContext`\[Beta]d$$], 0, 
       Row[{
        "Angle of \!\(\*\nStyleBox[SubscriptBox[\"F\", \"2\"],\n\
FontSlant->\"Italic\"]\)\!\(\*\nStyleBox[\" \",\nFontSlant->\"Italic\"]\): \!\
\(\*SubscriptBox[\(\[Alpha]\), \(2\)]\) (\[Degree])", 
         Spacer[0]}]}, 0, 360}, {{
       Hold[$CellContext`lr$$], 0, 
       Row[{
        "\!\(\*\nStyleBox[SubscriptBox[\"F\", \"2\"],\nFontSlant->\"Italic\"]\
\) position (m)", 
         Spacer[20]}]}, 0, 3}, {
      Hold[
       Grid[{{
          Manipulate`Place[1]}, {
          Manipulate`Place[2]}, {
          Manipulate`Place[3]}, {
          Manipulate`Place[4]}, {
          Manipulate`Place[5]}, {
          Manipulate`Place[6]}, {
          Manipulate`Place[7]}, {
          Manipulate`Place[8]}}, Alignment -> Left, 
        Spacings -> {Automatic, 1.5}]], Manipulate`Dump`ThisIsNotAControl}}, 
    Typeset`size$$ = {501., {267., 276.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`opa1$7099$$ = False, $CellContext`l$7100$$ = 
    0, $CellContext`F$7101$$ = 0, $CellContext`\[Alpha]d$7102$$ = 
    0, $CellContext`lf$7103$$ = 0, $CellContext`R$7104$$ = 
    0, $CellContext`\[Beta]d$7105$$ = 0, $CellContext`lr$7106$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`F$$ = 0, $CellContext`l$$ = 
        0, $CellContext`lf$$ = 0, $CellContext`lr$$ = 0, $CellContext`opa1$$ = 
        0, $CellContext`R$$ = 0, $CellContext`\[Alpha]d$$ = 
        0, $CellContext`\[Beta]d$$ = 0}, "ControllerVariables" :> {
        Hold[$CellContext`opa1$$, $CellContext`opa1$7099$$, False], 
        Hold[$CellContext`l$$, $CellContext`l$7100$$, 0], 
        Hold[$CellContext`F$$, $CellContext`F$7101$$, 0], 
        Hold[$CellContext`\[Alpha]d$$, $CellContext`\[Alpha]d$7102$$, 0], 
        Hold[$CellContext`lf$$, $CellContext`lf$7103$$, 0], 
        Hold[$CellContext`R$$, $CellContext`R$7104$$, 0], 
        Hold[$CellContext`\[Beta]d$$, $CellContext`\[Beta]d$7105$$, 0], 
        Hold[$CellContext`lr$$, $CellContext`lr$7106$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`size$, $CellContext`l0$, $CellContext`l1$, \
$CellContext`l2$, $CellContext`w$, $CellContext`\[Theta]$, $CellContext`\
\[Alpha]$, $CellContext`\[Beta]$, $CellContext`\[Gamma]$, $CellContext`t$, \
$CellContext`ts$, $CellContext`te$, $CellContext`dwf0$, $CellContext`dwf1$, \
$CellContext`dwf2$, $CellContext`dwf3$, $CellContext`dwf4$, \
$CellContext`dwf5$, $CellContext`dwf6$, $CellContext`dwf7$, \
$CellContext`dw1$, $CellContext`dw2$, $CellContext`an$, $CellContext`opa3$, \
$CellContext`opa4$, $CellContext`opa5$, $CellContext`opa7$, $CellContext`m$, \
$CellContext`ma$, $CellContext`ma2$, $CellContext`label$}, $CellContext`\
\[Alpha]$ = ($CellContext`\[Alpha]d$$/180) 
          Pi; $CellContext`\[Beta]$ = ($CellContext`\[Beta]d$$/180) 
          Pi; $CellContext`l0$ = 3; $CellContext`m$ = 
         3; $CellContext`l1$ = $CellContext`lf$$ - $CellContext`l$$; \
$CellContext`l2$ = $CellContext`lr$$ - $CellContext`l$$; $CellContext`w$ = 
         0.01 $CellContext`m$; $CellContext`size$ = 3.5; $CellContext`ts$ = 
         0; $CellContext`te$ = 15; $CellContext`\[Gamma]$ = 
         NDSolveValue[{(((1/
                 12) $CellContext`m$) $CellContext`l0$^2 + $CellContext`m$ ((
                   1/2) $CellContext`l0$ - $CellContext`l$$)^2) D[
               $CellContext`\[Theta]$[$CellContext`t$], {$CellContext`t$, 
                2}] == ($CellContext`F$$ $CellContext`l1$) 
              Sin[$CellContext`\[Alpha]$] + ($CellContext`R$$ \
$CellContext`l2$) Sin[$CellContext`\[Beta]$], $CellContext`\[Theta]$[0] == 0, 
            Derivative[1][$CellContext`\[Theta]$][0] == 
            0}, $CellContext`\[Theta]$, {$CellContext`t$, $CellContext`ts$, \
$CellContext`te$}]; $CellContext`ma$ = 
         If[((-$CellContext`F$$) $CellContext`l1$) 
            Sin[$CellContext`\[Alpha]$] != ($CellContext`R$$ $CellContext`l2$)
              Sin[$CellContext`\[Beta]$], (((($CellContext`F$$ \
$CellContext`l1$) 
               Sin[$CellContext`\[Alpha]$] + ($CellContext`R$$ \
$CellContext`l2$) Sin[$CellContext`\[Beta]$])/(3 $CellContext`l0$)) 2) Pi, 
           0]; $CellContext`ma2$ = 
         If[((-$CellContext`F$$) $CellContext`l1$) 
            Sin[$CellContext`\[Alpha]$] != ($CellContext`R$$ $CellContext`l2$)
              Sin[$CellContext`\[Beta]$], ($CellContext`F$$ $CellContext`l1$) 
            Sin[$CellContext`\[Alpha]$] + ($CellContext`R$$ $CellContext`l2$) 
            Sin[$CellContext`\[Beta]$], 0]; $CellContext`opa3$ = 
         If[$CellContext`F$$ != 0, 1, 0]; $CellContext`opa4$ = 
         If[$CellContext`R$$ != 0, 1, 0]; $CellContext`opa5$ = 
         If[$CellContext`\[Gamma]$[$CellContext`t$] != 0, 1, 
           0]; $CellContext`opa7$ = 
         If[$CellContext`ma$ != 0, 1, 0]; $CellContext`dwf0$ = {
           Opacity[$CellContext`opa1$$], 
           Dashing[{}], 
           Thickness[0.001], 
           Arrowheads[0.02], 
           Arrow[{{-$CellContext`size$, 0}, {$CellContext`size$, 0}}], 
           Arrow[{{0, -$CellContext`size$}, {0, $CellContext`size$}}], 
           Text[
           "\!\(\*\nStyleBox[\"x\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {
            0.95 $CellContext`size$, (-0.05) $CellContext`size$}], 
           Text[
           "\!\(\*\nStyleBox[\"y\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {(-0.05) $CellContext`size$, 
             0.95 $CellContext`size$}]}; $CellContext`dwf1$ = {
           
           Rectangle[{
            0, (((-1)/2) 2.5) $CellContext`w$}, {$CellContext`l0$, ((1/2) 
              2.5) $CellContext`w$}]}; $CellContext`dwf3$ = {
           Opacity[$CellContext`opa3$], 
           Thickness[0.005], 
           Arrowheads[0.04], 
           Arrow[{{$CellContext`l$$ + $CellContext`l1$ Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]], $CellContext`l1$ 
              Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]]}, {$CellContext`l$$ + \
$CellContext`l1$ Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]] + $CellContext`F$$ 
               Cos[$CellContext`\[Alpha]$ + \
$CellContext`\[Gamma]$[$CellContext`t$]], $CellContext`l1$ Sin[
                 $CellContext`\[Gamma]$[$CellContext`t$]] + $CellContext`F$$ 
               
               Sin[$CellContext`\[Alpha]$ + \
$CellContext`\[Gamma]$[$CellContext`t$]]}}], 
           Circle[{$CellContext`l$$ + $CellContext`l1$ Cos[
                $CellContext`\[Gamma]$[$CellContext`t$]], $CellContext`l1$ Sin[
               $CellContext`\[Gamma]$[$CellContext`t$]]}, 0.3, {
             $CellContext`\[Gamma]$[$CellContext`t$], $CellContext`\[Alpha]$ + \
$CellContext`\[Gamma]$[$CellContext`t$]}], 
           Text[
           "\!\(\*SubscriptBox[\n StyleBox[\"\[Alpha]\",\n\
FontWeight->\"Bold\"], \"1\"]\)", {$CellContext`l$$ + $CellContext`l1$ Cos[
                $CellContext`\[Gamma]$[$CellContext`t$]] + 
             0.55 Cos[$CellContext`\[Gamma]$[$CellContext`t$] + 
                0.5 $CellContext`\[Alpha]$], $CellContext`l1$ Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]] + 
             0.55 Sin[$CellContext`\[Gamma]$[$CellContext`t$] + 
                0.5 $CellContext`\[Alpha]$]}], 
           Text[
           "\!\(\*SubscriptBox[\n StyleBox[\"F\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"], \"1\"]\)", {$CellContext`l$$ + $CellContext`l1$ Cos[
                $CellContext`\[Gamma]$[$CellContext`t$]] + ($CellContext`F$$ + 
               0.2) Cos[$CellContext`\[Gamma]$[$CellContext`t$] + \
$CellContext`\[Alpha]$], $CellContext`l1$ Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]] + ($CellContext`F$$ + 
               0.2) Sin[$CellContext`\[Gamma]$[$CellContext`t$] + \
$CellContext`\[Alpha]$]}]}; $CellContext`dwf4$ = {
           Opacity[$CellContext`opa4$], 
           Thickness[0.005], 
           Arrowheads[0.04], 
           Arrow[{{$CellContext`l$$ + $CellContext`l2$ Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]], $CellContext`l2$ 
              Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]]}, {$CellContext`l$$ + \
$CellContext`l2$ Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]] + $CellContext`R$$ 
               Cos[$CellContext`\[Beta]$ + \
$CellContext`\[Gamma]$[$CellContext`t$]], $CellContext`l2$ Sin[
                 $CellContext`\[Gamma]$[$CellContext`t$]] + $CellContext`R$$ 
               Sin[$CellContext`\[Beta]$ + \
$CellContext`\[Gamma]$[$CellContext`t$]]}}], 
           Circle[{$CellContext`l$$ + $CellContext`l2$ Cos[
                $CellContext`\[Gamma]$[$CellContext`t$]], $CellContext`l2$ Sin[
               $CellContext`\[Gamma]$[$CellContext`t$]]}, 0.3, {
             $CellContext`\[Gamma]$[$CellContext`t$], $CellContext`\[Beta]$ + \
$CellContext`\[Gamma]$[$CellContext`t$]}], 
           Text[
           "\!\(\*\nStyleBox[SubscriptBox[\n  StyleBox[\"\[Alpha]\",\n\
FontWeight->\"Bold\"], \"2\"],\nFontWeight->\"Bold\"]\)", {$CellContext`l$$ + \
$CellContext`l2$ Cos[
                $CellContext`\[Gamma]$[$CellContext`t$]] + 
             0.55 Cos[$CellContext`\[Gamma]$[$CellContext`t$] + 
                0.5 $CellContext`\[Beta]$], $CellContext`l2$ Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]] + 
             0.55 Sin[$CellContext`\[Gamma]$[$CellContext`t$] + 
                0.5 $CellContext`\[Beta]$]}], 
           Text[
           "\!\(\*\nStyleBox[SubscriptBox[\n  StyleBox[\"F\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"], \"2\"],\nFontWeight->\"Bold\",\
\nFontSlant->\"Italic\"]\)", {$CellContext`l$$ + $CellContext`l2$ Cos[
                $CellContext`\[Gamma]$[$CellContext`t$]] + ($CellContext`R$$ + 
               0.2) Cos[$CellContext`\[Gamma]$[$CellContext`t$] + \
$CellContext`\[Beta]$], $CellContext`l2$ Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]] + ($CellContext`R$$ + 
               0.2) Sin[$CellContext`\[Gamma]$[$CellContext`t$] + \
$CellContext`\[Beta]$]}]}; $CellContext`dwf5$ = {
           Opacity[$CellContext`opa5$], Dashed, 
           Line[{{0, 0}, {$CellContext`l0$, 0}}]}; $CellContext`dwf6$ = {Red, 
           PointSize[0.02], 
           Point[{$CellContext`l$$, 0}], 
           
           Triangle[{{$CellContext`l$$, 0}, {$CellContext`l$$ - 0.3 
              Sin[Pi/6], (-0.3) Cos[Pi/6]}, {$CellContext`l$$ + 
              0.3 Sin[Pi/6], (-0.3) Cos[Pi/6]}}], 
           Thickness[0.005], 
           
           Line[{{$CellContext`l$$ - 0.3 Sin[Pi/6] - 0.1, (-0.3) 
              Cos[Pi/6]}, {$CellContext`l$$ + 0.3 Sin[Pi/6] + 0.1, (-0.3) 
              Cos[Pi/6]}}], 
           Thickness[0.001], 
           
           Line[{{$CellContext`l$$ - 0.3 Sin[Pi/6] - 0.1, (-0.3) 
              Cos[Pi/6]}, {$CellContext`l$$ - 0.3 Sin[Pi/6] - 0.1 - 0.1 
              Cos[Pi/3], (-0.3) Cos[Pi/6] - 0.1 Sin[Pi/3]}}], 
           
           Line[{{$CellContext`l$$ - 0.3 Sin[Pi/6], (-0.3) 
              Cos[Pi/6]}, {$CellContext`l$$ - 0.3 Sin[Pi/6] - 0.1 
              Cos[Pi/3], (-0.3) Cos[Pi/6] - 0.1 Sin[Pi/3]}}], 
           
           Line[{{$CellContext`l$$ - 0.3 Sin[Pi/6] + 0.1, (-0.3) 
              Cos[Pi/6]}, {$CellContext`l$$ - 0.3 Sin[Pi/6] + 0.1 - 0.1 
              Cos[Pi/3], (-0.3) Cos[Pi/6] - 0.1 Sin[Pi/3]}}], 
           
           Line[{{$CellContext`l$$ - 0.3 Sin[Pi/6] + 0.2, (-0.3) 
              Cos[Pi/6]}, {$CellContext`l$$ - 0.3 Sin[Pi/6] + 0.2 - 0.1 
              Cos[Pi/3], (-0.3) Cos[Pi/6] - 0.1 Sin[Pi/3]}}], 
           
           Line[{{$CellContext`l$$ - 0.3 Sin[Pi/6] + 0.3, (-0.3) 
              Cos[Pi/6]}, {$CellContext`l$$ - 0.3 Sin[Pi/6] + 0.3 - 0.1 
              Cos[Pi/3], (-0.3) Cos[Pi/6] - 0.1 Sin[Pi/3]}}], 
           
           Line[{{$CellContext`l$$ - 0.3 Sin[Pi/6] + 0.4, (-0.3) 
              Cos[Pi/6]}, {$CellContext`l$$ - 0.3 Sin[Pi/6] + 0.4 - 0.1 
              Cos[Pi/3], (-0.3) Cos[Pi/6] - 0.1 
              Sin[Pi/3]}}]}; $CellContext`dwf7$ = {
           Opacity[$CellContext`opa7$], 
           Thickness[0.005], 
           Arrowheads[0.03], 
           Arrow[
            Map[N[
              Table[{
                  Cos[$CellContext`k], 
                  Sin[$CellContext`k]} Part[#, 2] + 
               Part[#, 1], {$CellContext`k, 
                Part[#, 3], 
                Part[#, 4], (Part[#, 4] - Part[#, 3])/
                Part[#, 5]}]]& , {{{$CellContext`l$$, -1}, 0.3, 
               0, $CellContext`ma$, 100}}]], 
           Text[
           "\!\(\*\nStyleBox[\"M\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {$CellContext`l$$, -1}]}; $CellContext`label$ = 
         Text[
           Style[
            Row[{"t  = ", 
              NumberForm[$CellContext`t$, {4, 2}], 
              Spacer[15], 
              "\!\(\*\nStyleBox[\"M\",\nFontSlant->\"Italic\"]\)  = ", 
              NumberForm[$CellContext`ma2$, {3, 2}]}], 
            12]]; $CellContext`dw1$ = Graphics[{
            Rotate[$CellContext`dwf1$, 
             $CellContext`\[Gamma]$[$CellContext`t$], {$CellContext`l$$, 
              0}], $CellContext`dwf0$, $CellContext`dwf3$, \
$CellContext`dwf4$, $CellContext`dwf5$, $CellContext`dwf6$, \
$CellContext`dwf7$}, PlotRange -> $CellContext`size$, ImageSize -> 280, 
           PlotLabel -> 
           Pane[$CellContext`label$, Alignment -> {Center, Top}, ImageSize -> 
             300], Frame -> True]; $CellContext`an$ = Animate[
           Evaluate[
            
            ReplaceAll[$CellContext`dw1$, {$CellContext`t$ -> \
$CellContext`time}]], {{$CellContext`time, $CellContext`ts$, 
             "t"}, $CellContext`ts$, $CellContext`te$}, 
           DefaultDuration -> $CellContext`te$, AnimationRunning -> False, 
           ImageMargins -> Small]; $CellContext`an$], 
      "Specifications" :> {{{$CellContext`opa1$$, 0, 
          Row[{"Coordinates visibility", 
            Spacer[20]}]}, {1 -> "On", 0 -> "off"}, ControlType -> 
         RadioButton, ControlPlacement -> 1}, {{$CellContext`l$$, 0, 
          Row[{"Hinge position (m)", 
            Spacer[2]}]}, 0, 3, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 2}, {{$CellContext`F$$, 0, 
          
          Row[{"\!\(\*\nStyleBox[SubscriptBox[\"F\", \"1\"],\n\
FontSlant->\"Italic\"]\) magnitude (N)", 
            Spacer[7]}]}, -3, 3, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 3}, {{$CellContext`\[Alpha]d$$, 0, 
          
          Row[{"Angle of \!\(\*\nStyleBox[SubscriptBox[\"F\", \"1\"],\n\
FontSlant->\"Italic\"]\)\!\(\*\nStyleBox[\" \",\nFontSlant->\"Italic\"]\): \!\
\(\*SubscriptBox[\(\[Alpha]\), \(1\)]\) (\[Degree])", 
            Spacer[0]}]}, 0, 360, ImageSize -> Small, Appearance -> "Labeled",
          ControlPlacement -> 4}, {{$CellContext`lf$$, 0, 
          
          Row[{"\!\(\*\nStyleBox[SubscriptBox[\"F\", \"1\"],\n\
FontSlant->\"Italic\"]\) position (m)", 
            Spacer[20]}]}, 0, 3, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 5}, {{$CellContext`R$$, 0, 
          
          Row[{"\!\(\*\nStyleBox[SubscriptBox[\"F\", \"2\"],\n\
FontSlant->\"Italic\"]\) magnitude (N)", 
            Spacer[7]}]}, -3, 3, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 6}, {{$CellContext`\[Beta]d$$, 0, 
          
          Row[{"Angle of \!\(\*\nStyleBox[SubscriptBox[\"F\", \"2\"],\n\
FontSlant->\"Italic\"]\)\!\(\*\nStyleBox[\" \",\nFontSlant->\"Italic\"]\): \!\
\(\*SubscriptBox[\(\[Alpha]\), \(2\)]\) (\[Degree])", 
            Spacer[0]}]}, 0, 360, ImageSize -> Small, Appearance -> "Labeled",
          ControlPlacement -> 7}, {{$CellContext`lr$$, 0, 
          
          Row[{"\!\(\*\nStyleBox[SubscriptBox[\"F\", \"2\"],\n\
FontSlant->\"Italic\"]\) position (m)", 
            Spacer[20]}]}, 0, 3, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 8}, 
        Grid[{{
           Manipulate`Place[1]}, {
           Manipulate`Place[2]}, {
           Manipulate`Place[3]}, {
           Manipulate`Place[4]}, {
           Manipulate`Place[5]}, {
           Manipulate`Place[6]}, {
           Manipulate`Place[7]}, {
           Manipulate`Place[8]}}, Alignment -> Left, 
         Spacings -> {Automatic, 1.5}]}, 
      "Options" :> {ControlPlacement -> Left}, "DefaultOptions" :> {}],
     ImageSizeCache->{975., {312., 321.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center]
}, Open  ]]
},
WindowSize->{1366, 685},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
Magnification:>1.5 Inherited,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]]}, WindowSize -> {775, 561}, 
  WindowMargins -> {{50, Automatic}, {46, Automatic}}, FrontEndVersion -> 
  "11.0 for Microsoft Windows (64-bit) (July 28, 2016)", StyleDefinitions -> 
  "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 209, 7, 230, "Title"],
Cell[1698, 44, 2793, 80, 352, "Text"],
Cell[4494, 126, 18627, 361, 657, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature TxD918iRnFXEUCwNodp4Lutp *)
